#import "AppDelegate.h"


@implementation AppDelegate

static float factor = 5.0f;

-(void)awakeFromNib;
{
    [[window contentView] setWantsLayer:YES];
    [window setFrame:[[NSScreen mainScreen] frame] display:NO animate:NO];
    
	NSRect contentFrame = [[window contentView] frame];
    CALayer *root = [[window contentView] layer];
    
    // mainLayer is the layer that gets scaled. All of its sublayers
    // are automatically scaled with it.
    mainLayer = [CALayer layer];
    mainLayer.frame = NSRectToCGRect(contentFrame);
    
    // Make the background color to be a dark gray with a 50% alpha similar to
    // the real Dashbaord.
    mainLayer.backgroundColor = CGColorCreateGenericRGB(0.10, 0.10, 0.10, 0.50);
    [root insertSublayer:mainLayer above:0];

    // Add a new layer to the mainlayer.
    [self addNewLayer:nil];
    
	scaleUp = YES;
}

- (void)doItIn:(float)duration
{
    // Set the animation duration.
    [[NSAnimationContext currentContext] setDuration:duration];
    
	if( scaleUp )
	{
        // Scale everything (x, y, and z) by a factor of factor and reuce the opacity
        CATransform3D transform = CATransform3DMakeScale(factor, factor, factor);
        [mainLayer setTransform:transform];
		mainLayer.opacity = 0.0f;
        scaleUp = NO;
	}
	else
	{
        // Scale the rect back down to the orignal and bring up the opacity
        CATransform3D transform = CATransform3DMakeScale(1.0f, 1.0f, 1.0f);
        [mainLayer setTransform:transform];
        mainLayer.opacity = 1.0f;
		scaleUp = YES;
	}
 
}

- (IBAction)addNewLayer:(id)sender;
{
    
	CALayer *layer = [CALayer layer];
    
    // Set some random colors, and the border width
    float r = SSRandomFloatBetween(1.00, 0.00);
    float g = SSRandomFloatBetween(1.00, 0.00);
    float b = SSRandomFloatBetween(1.00, 0.00);
    
	layer.backgroundColor = CGColorCreateGenericRGB(r,g,b,1.0f);
	layer.borderColor=CGColorCreateGenericRGB(b,r,g,1.0f);
	layer.borderWidth=4.0;

    // Create a random rectangle with a size between 300 and 200 pixels.
    NSRect rect = NSZeroRect;
	rect.size = NSMakeSize( SSRandomFloatBetween( 300.0, 200.0 ), SSRandomFloatBetween( 300.0, 200.0 ));
	
	// Calculate random origin point
	rect.origin = SSRandomPointForSizeWithinRect( rect.size, [window frame] );
    
    // Set the layer frame to our random rectangle.
    layer.frame = NSRectToCGRect(rect);
	layer.cornerRadius = rect.size.height/5;
    
    // Create a text layer to add so we can see text scale too.
    CATextLayer *textLayer = [CATextLayer layer];
    textLayer.string = @"Hello World!";
    CGFontRef font = CGFontCreateWithFontName((CFStringRef)@"Helvetica");
    textLayer.font = font;
    textLayer.frame = CGRectMake(10.0, 100.0, 195.0, 35.0);
    CGFontRelease(font);
    
    // Use the same color for the text that we used for the border.
    textLayer.foregroundColor = layer.borderColor;
    // Add the text layer
    [layer addSublayer:textLayer];
    
    // Insert the layer into the root layer
	[mainLayer addSublayer:layer];

    
}

- (IBAction)doSlowScale:(id)sender;
{
    [self doItIn:5.0f];
}

- (IBAction)doScale:(id)sender;
{
    [self doItIn:0.40f];
}

@end
